package com.ruoyi.web.controller.oa;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcDeviceApproval;
import com.ruoyi.oa.service.ICmcDeviceApprovalService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * cmc设备审批Controller
 * 
 * @author cmc
 * @date 2024-03-05
 */
@RestController
@RequestMapping("/oa/deviceApproval")
public class CmcDeviceApprovalController extends BaseController
{
    @Autowired
    private ICmcDeviceApprovalService cmcDeviceApprovalService;

    /**
     * 查询cmc设备审批列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CmcDeviceApproval cmcDeviceApproval)
    {
        startPage();
        List<CmcDeviceApproval> list = cmcDeviceApprovalService.selectCmcDeviceApprovalList(cmcDeviceApproval);
        return getDataTable(list);
    }

    /**
     * 导出cmc设备审批列表
     */
    @Log(title = "cmc设备审批", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcDeviceApproval cmcDeviceApproval)
    {
        List<CmcDeviceApproval> list = cmcDeviceApprovalService.selectCmcDeviceApprovalList(cmcDeviceApproval);
        ExcelUtil<CmcDeviceApproval> util = new ExcelUtil<CmcDeviceApproval>(CmcDeviceApproval.class);
        util.exportExcel(response, list, "cmc设备审批数据");
    }

    /**
     * 获取cmc设备审批详细信息
     */
    @GetMapping(value = "/{deviceApplyId}")
    public AjaxResult getInfo(@PathVariable("deviceApplyId") String deviceApplyId)
    {
        return success(cmcDeviceApprovalService.selectCmcDeviceApprovalByDeviceApplyId(deviceApplyId));
    }

    /**
     * 新增cmc设备审批
     */
    @Log(title = "cmc设备审批", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcDeviceApproval cmcDeviceApproval)
    {
        return toAjax(cmcDeviceApprovalService.insertCmcDeviceApproval(cmcDeviceApproval));
    }

    /**
     * 修改cmc设备审批
     */
    @Log(title = "cmc设备审批", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcDeviceApproval cmcDeviceApproval)
    {
        return toAjax(cmcDeviceApprovalService.updateCmcDeviceApproval(cmcDeviceApproval));
    }

    /**
     * 删除cmc设备审批
     */
    @Log(title = "cmc设备审批", businessType = BusinessType.DELETE)
	@DeleteMapping("/{deviceApplyIds}")
    public AjaxResult remove(@PathVariable String[] deviceApplyIds)
    {
        return toAjax(cmcDeviceApprovalService.deleteCmcDeviceApprovalByDeviceApplyIds(deviceApplyIds));
    }
}
